Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2019-02-16 02:44:15 +0300
committerCampbell Barton <ideasman42@gmail.com>2019-02-16 02:44:15 +0300
commitec471a9b1c14ea5dcb855de7e570e27ad70661c5 (patch)
treeab84e5d466b440a0202ff6271f43484763902f79 /source/blender/editors/space_buttons/space_buttons.c
parent419911b1d19ceeb87cd1c0a7b78f0133bee4a6cd (diff)
DNA: rename SpaceButs -> SpaceProperties
Diffstat (limited to 'source/blender/editors/space_buttons/space_buttons.c')
-rw-r--r--source/blender/editors/space_buttons/space_buttons.c34
1 files changed, 17 insertions, 17 deletions
diff --git a/source/blender/editors/space_buttons/space_buttons.c b/source/blender/editors/space_buttons/space_buttons.c
index 6f59a373b6c..a4277666837 100644
--- a/source/blender/editors/space_buttons/space_buttons.c
+++ b/source/blender/editors/space_buttons/space_buttons.c
@@ -53,10 +53,10 @@
static SpaceLink *buttons_new(const ScrArea *UNUSED(area), const Scene *UNUSED(scene))
{
ARegion *ar;
- SpaceButs *sbuts;
+ SpaceProperties *sbuts;
- sbuts = MEM_callocN(sizeof(SpaceButs), "initbuts");
- sbuts->spacetype = SPACE_BUTS;
+ sbuts = MEM_callocN(sizeof(SpaceProperties), "initbuts");
+ sbuts->spacetype = SPACE_PROPERTIES;
sbuts->mainb = sbuts->mainbuser = BCONTEXT_OBJECT;
@@ -94,7 +94,7 @@ static SpaceLink *buttons_new(const ScrArea *UNUSED(area), const Scene *UNUSED(s
/* not spacelink itself */
static void buttons_free(SpaceLink *sl)
{
- SpaceButs *sbuts = (SpaceButs *) sl;
+ SpaceProperties *sbuts = (SpaceProperties *) sl;
if (sbuts->path)
MEM_freeN(sbuts->path);
@@ -113,7 +113,7 @@ static void buttons_init(struct wmWindowManager *UNUSED(wm), ScrArea *UNUSED(sa)
static SpaceLink *buttons_duplicate(SpaceLink *sl)
{
- SpaceButs *sbutsn = MEM_dupallocN(sl);
+ SpaceProperties *sbutsn = MEM_dupallocN(sl);
/* clear or remove stuff from old */
sbutsn->path = NULL;
@@ -129,11 +129,11 @@ static void buttons_main_region_init(wmWindowManager *wm, ARegion *ar)
ED_region_panels_init(wm, ar);
- keymap = WM_keymap_ensure(wm->defaultconf, "Property Editor", SPACE_BUTS, 0);
+ keymap = WM_keymap_ensure(wm->defaultconf, "Property Editor", SPACE_PROPERTIES, 0);
WM_event_add_keymap_handler(&ar->handlers, keymap);
}
-static void buttons_main_region_layout_properties(const bContext *C, SpaceButs *sbuts, ARegion *ar)
+static void buttons_main_region_layout_properties(const bContext *C, SpaceProperties *sbuts, ARegion *ar)
{
buttons_context_compute(C, sbuts);
@@ -310,7 +310,7 @@ static void buttons_main_region_layout_tool(const bContext *C, ARegion *ar)
static void buttons_main_region_layout(const bContext *C, ARegion *ar)
{
/* draw entirely, view changes should be handled here */
- SpaceButs *sbuts = CTX_wm_space_buts(C);
+ SpaceProperties *sbuts = CTX_wm_space_properties(C);
if (sbuts->mainb == BCONTEXT_TOOL) {
buttons_main_region_layout_tool(C, ar);
@@ -345,7 +345,7 @@ static void buttons_operatortypes(void)
static void buttons_keymap(struct wmKeyConfig *keyconf)
{
- WM_keymap_ensure(keyconf, "Property Editor", SPACE_BUTS, 0);
+ WM_keymap_ensure(keyconf, "Property Editor", SPACE_PROPERTIES, 0);
}
/* add handlers, stuff you only do once or on area/region changes */
@@ -363,7 +363,7 @@ static void buttons_header_region_init(wmWindowManager *UNUSED(wm), ARegion *ar)
static void buttons_header_region_draw(const bContext *C, ARegion *ar)
{
- SpaceButs *sbuts = CTX_wm_space_buts(C);
+ SpaceProperties *sbuts = CTX_wm_space_properties(C);
/* Needed for RNA to get the good values! */
buttons_context_compute(C, sbuts);
@@ -377,14 +377,14 @@ static void buttons_header_region_message_subscribe(
bScreen *UNUSED(screen), ScrArea *sa, ARegion *ar,
struct wmMsgBus *mbus)
{
- SpaceButs *sbuts = sa->spacedata.first;
+ SpaceProperties *sbuts = sa->spacedata.first;
wmMsgSubscribeValue msg_sub_value_region_tag_redraw = {
.owner = ar,
.user_data = ar,
.notify = ED_region_do_msg_notify_tag_redraw,
};
/* Don't check for SpaceButs.mainb here, we may toggle between view-layers
* where one has no active object, so that available contexts changes. */
WM_msg_subscribe_rna_anon_prop(mbus, Window, view_layer, &msg_sub_value_region_tag_redraw);
@@ -403,7 +403,7 @@ static void buttons_header_region_message_subscribe(
static void buttons_navigation_bar_region_init(wmWindowManager *wm, ARegion *ar)
{
- wmKeyMap *keymap = WM_keymap_ensure(wm->defaultconf, "Property Editor", SPACE_BUTS, 0);
+ wmKeyMap *keymap = WM_keymap_ensure(wm->defaultconf, "Property Editor", SPACE_PROPERTIES, 0);
WM_event_add_keymap_handler(&ar->handlers, keymap);
ar->flag |= RGN_FLAG_PREFSIZE_OR_HIDDEN;
@@ -443,7 +443,7 @@ static void buttons_navigation_bar_region_message_subscribe(
* showing that button set, to reduce unnecessary drawing. */
static void buttons_area_redraw(ScrArea *sa, short buttons)
{
- SpaceButs *sbuts = sa->spacedata.first;
+ SpaceProperties *sbuts = sa->spacedata.first;
/* if the area's current button set is equal to the one to redraw */
if (sbuts->mainb == buttons)
@@ -454,7 +454,7 @@ static void buttons_area_redraw(ScrArea *sa, short buttons)
static void buttons_area_listener(
wmWindow *UNUSED(win), ScrArea *sa, wmNotifier *wmn, Scene *UNUSED(scene))
{
- SpaceButs *sbuts = sa->spacedata.first;
+ SpaceProperties *sbuts = sa->spacedata.first;
/* context changes */
switch (wmn->category) {
@@ -636,7 +636,7 @@ static void buttons_area_listener(
static void buttons_id_remap(ScrArea *UNUSED(sa), SpaceLink *slink, ID *old_id, ID *new_id)
{
- SpaceButs *sbuts = (SpaceButs *)slink;
+ SpaceProperties *sbuts = (SpaceProperties *)slink;
if (sbuts->pinid == old_id) {
sbuts->pinid = new_id;
@@ -693,7 +693,7 @@ void ED_spacetype_buttons(void)
SpaceType *st = MEM_callocN(sizeof(SpaceType), "spacetype buttons");
ARegionType *art;
- st->spaceid = SPACE_BUTS;
+ st->spaceid = SPACE_PROPERTIES;
strncpy(st->name, "Buttons", BKE_ST_MAXNAME);
st->new = buttons_new;
@@ -377,14 +377,14 @@ static void buttons_header_region_message_subscribe(
.notify = ED_region_do_msg_notify_tag_redraw,
};
- /* Don't check for SpaceButs.mainb here, we may toggle between view-layers
+ /* Don't check for SpaceProperties.mainb here, we may toggle between view-layers
* where one has no active object, so that available contexts changes. */
WM_msg_subscribe_rna_anon_prop(mbus, Window, view_layer, &msg_sub_value_region_tag_redraw);